==> agnostos-0.9.7.tar.gz: agnostos/agnostos_docroot/name_manage.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;

#--------------------------------------------------------------------------
# main

my $dbh=dbserver_connect("agnostos");
my ($id, $name, $dbq, $tmpid, $tmpname, $numrows, $field_name);
my $query = new CGI;
my $table = $query -> param('table');

($id, $name) = get_table($table);

print html_header("Edit ".$table."s", $query);
print "<h2> Edit ".$table."s</h2>\n";

$dbq = $dbh -> prepare("select $id, $name from $table");
$numrows = $dbq -> execute;

if ( $numrows > 0 ) {
    print "<form action=name_edit.pl method=post>\n";
    print "<table>\n";
    
    while (($tmpid, $tmpname) = $dbq -> fetchrow_array) {
	$field_name="entname_".$tmpid;
	unless ($tmpname eq 'UNSET') {
	    print "<tr><td><input type=text size=40 value=\"$tmpname\" name=$field_name>\n";
	}
    }
    print "</table><input type=hidden name=table value=$table>\n";
    print "<input type=submit value=\"Update\"></form>\n";
}

else {
    print "No existing $table"."s; please add one using the form below\n";
}

$dbq -> finish;
print "<hr><h2>Add new $table</h2>\n";
print "<p><form action=add_name.pl method=post>\n";
print "<table><tr><td>Enter new $table: <td> <input type=text size=40 name=newuser>\n";
print "<input type=hidden name=table value=$table>\n";
print "<td><input type=submit value=\"Add\"></table></form>\n";
print "</body></html>\n";

$dbh -> disconnect;

==> agnostos-0.9.10.tar.gz: agnostos/agnostos_docroot/name_manage.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;
use CGI::Carp qw(fatalsToBrowser);

#--------------------------------------------------------------------------
# main

my %config = get_config();
my $dbh=dbserver_connect(\%config);
my ($id, $name, $dbq, $tmpid, $tmpname, $numrows, $field_name);
my $query = new CGI;
my $table = $query -> param('table');

($id, $name) = get_table($table);

print html_header("Edit ".$table."s", $query);
print "<h2> Edit ".$table."s</h2>\n";

$dbq = $dbh -> prepare("select $id, $name from $table");
$numrows = $dbq -> execute;

if ( $numrows > 0 ) {
    print "<form action=name_edit.pl method=post>\n";
    print "<table>\n";
    
    while (($tmpid, $tmpname) = $dbq -> fetchrow_array) {
	$field_name="entname_".$tmpid;
	unless ($tmpname eq 'UNSET') {
	    print "<tr><td><input type=text size=40 value=\"$tmpname\" name=$field_name>\n";
	}
    }
    print "</table><input type=hidden name=table value=$table>\n";
    print "<input type=submit value=\"Update\"></form>\n";
}

else {
    print "No existing $table"."s; please add one using the form below\n";
}

$dbq -> finish;
print "<hr><h2>Add new $table</h2>\n";
print "<p><form action=add_name.pl method=post>\n";
print "<table><tr><td>Enter new $table: <td> <input type=text size=40 name=newuser>\n";
print "<input type=hidden name=table value=$table>\n";
# If adding a new user, show password fields
if ($config{auth_inuse} && $table eq 'user') {
    print "<tr><td>Password<td><input type=password size=20 name=passwd>\n";
    print "<tr><td>Password again<td><input type=password size=20 name=passwd2>\n";
}

print "<tr><td><input type=submit value=\"Add\"></table></form>\n";
print "</body></html>\n";

$dbh -> disconnect;
